@@ -177,8 +177,8 @@ camel_provider_module_init (void)
 
 	bindtextdomain (GETTEXT_PACKAGE, CONNECTOR_LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-	exchange_provider.translation_domain = GETTEXT_PACKAGE;
-	exchange_provider.translation_domain = GETTEXT_PACKAGE;
+	exchange_provider.translation_domain = (gchar *) GETTEXT_PACKAGE;
+	exchange_provider.translation_domain = (gchar *) GETTEXT_PACKAGE;
 
 	/* 'auth_types' is not used anywhere else, it's there just for localization of the 'al_auth' */
 	for (i = 0; auth_types [i]; i++) {
